summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorEmmanuel Bourg <ebourg@apache.org>2017-01-12 09:34:20 +0100
committerStefan Bodewig <bodewig@apache.org>2017-01-12 17:29:53 +0100
commit0c38fb606fd48312925a95814b37f8f0fa277127 (patch)
tree18653a87c7dd6058bfc468886707b82b3293a495 /src
parent2960860847a1d35afde3810b29183f1387fb71d6 (diff)
downloadant-0c38fb606fd48312925a95814b37f8f0fa277127.tar.gz
Fixed a typo (instanciated -> instantiated)
Diffstat (limited to 'src')
-rw-r--r--src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java4
-rw-r--r--src/main/org/apache/tools/ant/ProjectHelperRepository.java2
2 files changed, 3 insertions, 3 deletions
diff --git a/src/main/org/apache/tools/ant/ProjectHelperRepository.java b/src/main/org/apache/tools/ant/ProjectHelperRepository.java
index 7fe92c491..e370a54c7 100644
--- a/src/main/org/apache/tools/ant/ProjectHelperRepository.java
+++ b/src/main/org/apache/tools/ant/ProjectHelperRepository.java
@@ -46,7 +46,7 @@ public class ProjectHelperRepository {
"ant.project-helper-repo.debug";
// The message log level is not accessible here because everything
- // is instanciated statically
+ // is instantiated statically
private static final boolean DEBUG =
"true".equals(System.getProperty(DEBUG_PROJECT_HELPER_REPOSITORY));
diff --git a/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java b/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java
index 1ede565a8..ed3331fbd 100644
--- a/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java
+++ b/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java
@@ -48,7 +48,7 @@ public class ArgumentProcessorRegistry {
private static final String DEBUG_ARGUMENT_PROCESSOR_REPOSITORY = "ant.argument-processor-repo.debug";
// The message log level is not accessible here because everything
// is instanciated statically
private static final boolean DEBUG = "true".equals(System.getProperty(DEBUG_ARGUMENT_PROCESSOR_REPOSITORY));
private static final String SERVICE_ID = "META-INF/services/org.apache.tools.ant.ArgumentProcessor";
@@ -128,7 +128,7 @@ public class ArgumentProcessorRegistry {
} catch (Exception e) {
throw new BuildException("The argument processor class"
+ processorClass.getClass().getName()
- + " could not be instanciated with a default constructor",
+ + " could not be instantiated with a default constructor",
e);
}
return processor;
@@ -48,7 +48,7 @@ public class ArgumentProcessorRegistry {
private static final String DEBUG_ARGUMENT_PROCESSOR_REPOSITORY = "ant.argument-processor-repo.debug";
// The message log level is not accessible here because everything
- // is instanciated statically
+ // is instantiated statically
private static final boolean DEBUG = "true".equals(System.getProperty(DEBUG_ARGUMENT_PROCESSOR_REPOSITORY));
private static final String SERVICE_ID = "META-INF/services/org.apache.tools.ant.ArgumentProcessor";